@@ -2,7 +2,7 @@ import pandas as pd
 import os
 
 
-__all__ = ['TransmissionProblem']
+__all__ = ["TransmissionProblem"]
 
 current_dir = os.path.dirname(os.path.abspath(__file__))
 
@@ -12,7 +12,7 @@ class TransmissionProblem(object):
 
         try:
             csvfile = "https://raw.githubusercontent.com/pnnl/HyperNetX/master/hypernetx/utils/toys/ChungLuTransmissionData.csv"
-            self.df = pd.read_csv(csvfile, header=None, names=['receivers', 'senders'])
+            self.df = pd.read_csv(csvfile, header=None, names=["receivers", "senders"])
         except:
-            csvfile = f'{current_dir}/ChungLuTransmissionData.csv'
-            self.df = pd.read_csv(csvfile, header=None, names=['receivers', 'senders'])
+            csvfile = f"{current_dir}/ChungLuTransmissionData.csv"
+            self.df = pd.read_csv(csvfile, header=None, names=["receivers", "senders"])
